@@ -1,7 +1,6 @@
-from contextlib import contextmanager\
+from contextlib import contextmanager
 
 import blinker
-import aiosmtplib
 from pydantic import BaseModel
 
 from fastapi_mail.config import ConnectionConfig
@@ -54,13 +53,13 @@ class FastMail(_MailMixin):
         self.config = config
 
     async def get_mail_template(self, env_path, template_name):
-        template = env_path.get_template(template_name)
-        return template
+        return env_path.get_template(template_name)
 
     async def __prepare_message(self, message: MessageSchema, template=None):
         if template is not None:
-            if message.body and not message.html:
-                message.body = template.render(body=message.body)
+            template_body = message.template_body
+            if template_body and not message.html:
+                message.template_body = template.render(body=template_body)
                 message.subtype = "html"
             elif message.html:
                 message.html = template.render(body=message.html)
@@ -76,11 +75,11 @@ class FastMail(_MailMixin):
 
         if not issubclass(message.__class__, BaseModel):
             raise PydanticClassRequired('''Message schema should be provided from MessageSchema class, check example below:
-         \nfrom fastmail import MessageSchema  \nmessage = MessageSchema(\nsubject = "subject",\nrecipients= ["list_of_recipients"],\nbody = "Hello World",\ncc = ["list_of_recipients"],\nbcc =["list_of_recipients"],\nsubtype="plain")
+         \nfrom fastmail import MessageSchema  \nmessage = MessageSchema(\nsubject = "subject",\nrecipients = ["list_of_recipients"],\nbody = "Hello World",\ncc = ["list_of_recipients"],\nbcc = ["list_of_recipients"],\nreply_to = ["list_of_recipients"],\nsubtype = "plain")
          ''')
 
         if self.config.TEMPLATE_FOLDER and template_name:
-            template = await self.get_mail_template(self.config.TEMPLATE_FOLDER, template_name)
+            template = await self.get_mail_template(self.config.template_engine(), template_name)
             msg = await self.__prepare_message(message, template)
         else:
             msg = await self.__prepare_message(message)
