@@ -1,5 +1,6 @@
 import time
 import sys
+import warnings
 from email.mime.text import MIMEText
 from email.mime.base import MIMEBase
 from email.mime.multipart import MIMEMultipart
@@ -8,6 +9,7 @@ from email.encoders import encode_base64
 
 PY3 = sys.version_info[0] == 3
 
+
 class MailMsg:
     """
     Preaparation of class for email text
@@ -15,12 +17,14 @@ class MailMsg:
     :param subject: email subject header
     :param recipients: list of email addresses
     :param body: plain text message
+    :param template_body: Data to pass into chosen Jinja2 template
     :param html: HTML message
     :param subtype: type of body parameter - "plain" or "html". Ignored if
     the html parameter is explicitly specified
     :param sender: email sender address
     :param cc: CC list
     :param bcc: BCC list
+    :param reply_to: Reply-To list
     :param attachments: list of Attachment instances
     :param multipart_subtype: MultipartSubtypeEnum instance. Determines the
     nature of the parts of the message and their relationship to each other
@@ -66,7 +70,7 @@ class MailMsg:
 
     async def _message(self, sender):
         """Creates the email message"""
-            
+
         self.message = MIMEMultipart(self.multipart_subtype.value)
 
         self.message.set_charset(self.charset)
@@ -84,13 +88,21 @@ class MailMsg:
         if self.bcc:
             self.message["Bcc"] = ', '.join(self.bcc)
 
-        if self.body:
-            if not self.html and self.subtype:
-                self.message.attach(self._mimetext(self.body, self.subtype))
-            else:
-                self.message.attach(self._mimetext(self.body))
+        if self.reply_to:
+            self.message["Reply-To"] = ', '.join(self.reply_to)
 
-        if self.html:
+        if self.body:
+            self.message.attach(self._mimetext(self.body))
+
+        if self.template_body or self.body:
+            if not self.html and self.subtype == 'html':
+                if self.body:
+                    warnings.warn("Use ``template_body`` instead of ``body`` to pass data into Jinja2 template",
+                                  DeprecationWarning)
+                self.message.attach(self._mimetext(self.template_body or self.body, self.subtype))
+            elif self.template_body:
+                raise ValueError("tried to send jinja2 template and html")
+        elif self.html:
             self.message.attach(self._mimetext(self.html, "html"))
 
         if self.attachments:
