@@ -1,8 +1,8 @@
-import os
+from pathlib import Path
+
 import pytest
 import fakeredis.aioredis
 from fastapi_mail.email_utils import DefaultChecker
-from fastapi_mail.config import ConnectionConfig
 
 
 @pytest.fixture
@@ -25,8 +25,8 @@ async def redis_checker(scope="redis_config"):
 
 @pytest.fixture(autouse=True)
 def mail_config():
-    directory = os.getcwd()
-    html  = directory + "/files"
+    home: Path = Path(__file__).parent.parent
+    html = home / "files"
     env = {
         "MAIL_USERNAME": "example@test.com",
         "MAIL_PASSWORD":"strong",
@@ -39,8 +39,8 @@ def mail_config():
         "MAIL_DEBUG": 0,
         "SUPPRESS_SEND": 1,
         "USE_CREDENTIALS": False,
+        "VALIDATE_CERTS": False,
         "TEMPLATE_FOLDER": html,
-
     }
 
     yield env
